needTenantByDefault property
When true, calls inject the x-tenant-id header by default.
Individual calls can still override via their own needTenant flag.
Implementation
final bool needTenantByDefault;
When true, calls inject the x-tenant-id header by default.
Individual calls can still override via their own needTenant flag.
final bool needTenantByDefault;