ApiCallResponse class

Constructors

ApiCallResponse(dynamic jsonBody, Pagination? pagination, ApiError? error, Map<String, String> headers, int statusCode, {Response? response})
const

Properties

bodyText String
no setter
error ApiError?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
jsonBody → dynamic
final
jsonList List
jsonBody come List — gestisce sia List diretta che Map con "data"/"items". Ritorna sempre una List (vuota se il body non contiene dati lista).
no setter
jsonMap Map<String, dynamic>
jsonBody come Map — sicuro, ritorna {} se il body non è un map.
no setter
pagination Pagination?
final
response → Response?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
succeeded bool
no setter
unauthenticated bool
no setter

Methods

getHeader(String headerName) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromHttpResponse(Response response, bool returnBody, bool decodeUtf8) Future<ApiCallResponse>