bind static method
Binds the global CLAuthState instance. Must be called once at app startup before any consumer reads authState.
Implementation
static void bind(CLAuthState state) => instance._authState = state;
Binds the global CLAuthState instance. Must be called once at app startup before any consumer reads authState.
static void bind(CLAuthState state) => instance._authState = state;