CLAuthState class abstract

Classe astratta per la gestione dell'autenticazione. Ogni app implementa la propria versione concreta (OIDC, email/password, ecc.)

Inheritance

Constructors

CLAuthState()

Properties

accessToken String?
Token di accesso (Bearer token per le API)
no setter
currentTenant CLTenant?
no setter
currentUserInfo CLUserInfo?
Informazioni utente in formato generico
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isAuthenticated bool
no setter
isAuthenticating bool
no setter
isLoading bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantList List<CLTenant>
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
can(String action, String subject, {Map<String, dynamic>? resource}) bool
checkTenantContext(String tenantContext) bool
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setCurrentTenant(CLTenant? tenant) → void
signIn(BuildContext context) Future<void>
signOut() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited