CLTenant class abstract

Interfaccia generica per un tenant (organizzazione/azienda). Ogni app implementa il proprio modello concreto.

Constructors

CLTenant()

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
no setter
name String
no setter
rawData Map<String, dynamic>
Dati raw completi (per accesso a campi custom)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited