CLUserInfo class abstract

Interfaccia generica per le informazioni utente. Ogni app implementa il proprio mapping dai dati raw.

Constructors

CLUserInfo()

Properties

email String?
no setter
firstName String
no setter
fullName String
no setter
hashCode int
The hash code for this object.
no setterinherited
lastName String
no setter
rawData Map<String, dynamic>
Dati raw completi (per accesso a campi custom)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited