CLTheme class abstract

--- Theme root ----------------------------------------------------------

Implementers

Constructors

CLTheme({required Color primary, required Color secondary, required Color alternate, required Color primaryText, required Color secondaryText, required Color primaryBackground, required Color secondaryBackground, required Color tertiaryBackground, required Color success, required Color warning, required Color danger, required Color info, required Color borderColor, required Color background, required Color fillColor, required Color muted, required Color mutedForeground, required Color accent, required Color accentForeground, required Color ring, required Color cardBorder, required Color idColor, required Color certColor, required Color hrColor, required Color lmsColor})
const

Properties

accent Color
final
accentForeground Color
final
alternate Color
final
background Color
final
bodyLabel TextStyle
no setter
bodyLabelTableHead TextStyle
no setter
bodyText TextStyle
no setter
borderColor Color
final
cardBorder Color
final
cardShadow List<BoxShadow>
no setter
certColor Color
Colore identificativo del modulo Certificazioni
final
danger Color
final
fillColor Color
final
hashCode int
The hash code for this object.
no setterinherited
heading1 TextStyle
--------- Getter compatibili (no refactor in app) ----------
no setter
heading2 TextStyle
no setter
heading3 TextStyle
no setter
heading4 TextStyle
no setter
heading5 TextStyle
no setter
heading6 TextStyle
no setter
hrColor Color
Colore identificativo del modulo HR
final
idColor Color
Colore identificativo del modulo SkillID
final
info Color
final
lmsColor Color
Colore identificativo del modulo LMS
final
muted Color
final
mutedForeground Color
final
primary Color
final
primaryBackground Color
final
primaryText Color
final
ring Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
final
secondaryBackground Color
final
secondaryText Color
final
smallLabel TextStyle
no setter
smallText TextStyle
no setter
subTitle TextStyle
no setter
success Color
final
tertiaryBackground Color
final
title TextStyle
no setter
typography Typography
Typography provider
no setter
warning Color
final

Methods

generateColorFromText(String text) Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

themeMode ThemeMode
no setter

Static Methods

hexToColor(String code) Color
of(BuildContext context) CLTheme
saveThemeMode(ThemeMode mode) Future<void>
toHex(Color color, {bool leadingHashSign = true}) String

Constants

dark → const CLTheme
light → const CLTheme