LightModeTheme class

Inheritance

Constructors

LightModeTheme({Color primary = const Color(0xFF0C8EC7), Color secondary = const Color(0xFF0A7AAD), Color alternate = const Color(0xFFE8EBF0), Color primaryText = const Color(0xF2000000), Color secondaryText = const Color(0xFF615D59), Color primaryBackground = const Color(0xFFF6F6FA), Color secondaryBackground = const Color(0xFFFFFFFF), Color tertiaryBackground = const Color(0xFFECEBE9), Color success = const Color(0xFF16A34A), Color warning = const Color(0xFFD97706), Color danger = const Color(0xFFDC2626), Color info = const Color(0xFF0C8EC7), Color borderColor = const Color(0x1A000000), Color background = const Color(0xFFF6F5F4), Color fillColor = const Color(0xFFF6F5F4), Color muted = const Color(0xFFF2F1EF), Color mutedForeground = const Color(0xFFA39E98), Color accent = const Color(0xFFF2F1EF), Color accentForeground = const Color(0xFF31302E), Color ring = const Color(0xFF097FE8), Color cardBorder = const Color(0x1A000000), Color idColor = const Color(0xFF0C8EC7), Color certColor = const Color(0xFF7C3AED), Color hrColor = const Color(0xFFE17B47), Color lmsColor = const Color(0xFF059669)})
const

Properties

accent Color
finalinherited
accentForeground Color
finalinherited
alternate Color
finalinherited
background Color
finalinherited
bodyLabel TextStyle
no setterinherited
bodyLabelTableHead TextStyle
no setterinherited
bodyText TextStyle
no setterinherited
borderColor Color
finalinherited
cardBorder Color
finalinherited
cardShadow List<BoxShadow>
no setteroverride
certColor Color
Colore identificativo del modulo Certificazioni
finalinherited
danger Color
finalinherited
fillColor Color
finalinherited
hashCode int
The hash code for this object.
no setterinherited
heading1 TextStyle
--------- Getter compatibili (no refactor in app) ----------
no setterinherited
heading2 TextStyle
no setterinherited
heading3 TextStyle
no setterinherited
heading4 TextStyle
no setterinherited
heading5 TextStyle
no setterinherited
heading6 TextStyle
no setterinherited
hrColor Color
Colore identificativo del modulo HR
finalinherited
idColor Color
Colore identificativo del modulo SkillID
finalinherited
info Color
finalinherited
lmsColor Color
Colore identificativo del modulo LMS
finalinherited
muted Color
finalinherited
mutedForeground Color
finalinherited
primary Color
finalinherited
primaryBackground Color
finalinherited
primaryText Color
finalinherited
ring Color
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
finalinherited
secondaryBackground Color
finalinherited
secondaryText Color
finalinherited
smallLabel TextStyle
no setterinherited
smallText TextStyle
no setterinherited
subTitle TextStyle
no setterinherited
success Color
finalinherited
tertiaryBackground Color
finalinherited
title TextStyle
no setterinherited
typography Typography
Typography provider
no setterinherited
warning Color
finalinherited

Methods

generateColorFromText(String text) Color
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited