City class

Inheritance

Constructors

City({String id = "", String name = "", List<String> zips = const [], String code = "", String cadastralCode = "", String provinceId = "", required Province province})
factory
City.fromJson({required dynamic jsonObject})
factory

Properties

cadastralCode String
getter/setter pair
code String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
modelIdentifier String
no setteroverride
name String
getter/setter pair
province Province
getter/setter pair
provinceId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zips List<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited