Country class

Inheritance

Constructors

Country({String id = "", String name = "", String slug = "", List<State> states = const []})
factory
Country.fromJson({required dynamic jsonObject})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
modelIdentifier String
no setteroverride
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
getter/setter pair
states List<State>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited