Province class

Inheritance

Constructors

Province({String id = "", String slug = "", String name = "", String code = "", String stateId = "", required State state, List<City> cities = const []})
factory
Province.fromJson({required dynamic jsonObject})
factory

Properties

cities List<City>
getter/setter pair
code String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
modelIdentifier String
no setteroverride
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
getter/setter pair
state State?
getter/setter pair
stateId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited