State class

Inheritance

Constructors

State({String id = "", String code = "", String name = "", String countryId = "", required Country country, List<Province> provinces = const []})
factory
State.fromJson({required dynamic jsonObject})
factory

Properties

code String
getter/setter pair
country Country?
getter/setter pair
countryId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
modelIdentifier String
no setteroverride
name String
getter/setter pair
provinces List<Province>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited