Tolerances class

Tolleranze per il calcolo delle anomalie nei turni. Usato da WorkSchedule e configurazione profili orari.

Inheritance

Constructors

Tolerances({int earlyIn = 15, int lateIn = 10, int earlyOut = 5, int lateOut = 30})
Tolerances.fromJson({required dynamic jsonObject})
factory

Properties

earlyIn int
getter/setter pair
earlyOut int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lateIn int
getter/setter pair
lateOut int
getter/setter pair
modelIdentifier String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited