FFUploadedFile class

Constructors

FFUploadedFile({required CLMedia clMedia, double? height, double? width, String? mimeType})
const

Properties

clMedia CLMedia
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
mimeType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

deserialize(String jsonString) FFUploadedFile
fromXFile(XFile file) Future<FFUploadedFile>
🔄 Crea un oggetto FFUploadedFile da un XFile