CLBaseViewModel class

Inheritance
Available extensions

Constructors

CLBaseViewModel({required BuildContext viewContext, required VMType viewModelType, dynamic extraParams})

Properties

anyObjectsBusy bool
no setterinherited
disposed bool
getter/setter pairinherited
extraParams ↔ dynamic
getter/setter pair
hasError bool
Returns the error existence status of the ViewModel
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
initialised bool
no setterinherited
isBusy bool
Returns the busy status of the ViewModel
no setterinherited
isEdit bool
getter/setter pair
modelError → dynamic
Returns the error status of the ViewModel
no setterinherited
onModelReadyCalled bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewContext BuildContext
getter/setter pair
viewModelType VMType
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
busy(Object? object) bool
Returns the busy status for an object if it exists. Returns false if not present
inherited
clearErrors() → void
Clears all the errors
inherited
deleteAllData() Future
dispose() → void
Discards any resources used by the object.
inherited
error(Object object) → dynamic
inherited
hasErrorForKey(Object key) bool
Returns a boolean that indicates if the ViewModel has an error for the key
inherited
initialize({List<PageAction>? pageActions}) Future
logout() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onFutureError(dynamic error, Object? key) → void
Function that is called when a future throws an error
inherited
rebuildUi() → void
Calls the builder function with this updated viewmodel
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
runBusyFuture<T>(Future<T> busyFuture, {Object? busyObject, bool throwException = false}) Future<T>
Sets the ViewModel to busy, runs the future and then sets it to not busy when complete.
inherited
runErrorFuture<T>(Future<T> future, {Object? key, bool throwException = false}) Future<T>
inherited
safeCall<R>({required Future<ApiCallResponse> call(), R onSuccess(dynamic data)?, String errorTitle = 'Errore', String? errorMessage, bool showErrorAlert = true, bool manageBusy = true}) Future<R?>

Available on CLBaseViewModel, provided by the SafeCallExtension extension

Wraps an ApiCallResponse-producing call with busy state and error handling.
setBusy(bool value) → void
Marks the ViewModel as busy and calls notify listeners
inherited
setBusyForObject(Object? object, bool value) → void
Sets the busy state for the object equal to the value passed in and notifies Listeners If you're using a primitive type the value SHOULD NOT BE CHANGED, since Hashcode uses == value
inherited
setError(dynamic error) → void
Sets the error for the ViewModel
inherited
setErrorForModelOrObject(dynamic value, {Object? key}) → void
inherited
setErrorForObject(Object object, dynamic value) → void
Sets the error state for the object equal to the value passed in and notifies Listeners If you're using a primitive type the value SHOULD NOT BE CHANGED, since Hashcode uses == value
inherited
setInitialised(bool value) → void
Sets the initialised value for the ViewModel to true. This is called after the first initialise special ViewModel call
inherited
setOnModelReadyCalled(bool value) → void
Sets the onModelReadyCalled value to true. This is called after this first onModelReady call
inherited
skeletonData<T>({required T? realData, required T busyData, Object? busyKey}) → T
returns real data passed if neither the model is busy nor the object passed is busy
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited