CityGraphData class

Inheritance

Constructors

CityGraphData({required String key, required int value})
CityGraphData.fromJson({required dynamic jsonObject})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
getter/setter pair
modelIdentifier String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited