PageAction class

Azione contestuale di pagina — usata per creare bottoni nel CLPageHeader.

Constructors

PageAction({required String title, IconData? iconData, VoidCallback? onTap, bool isMain = false, bool isSecondary = false, bool needConfirmation = false, String? confirmationTitle, String? confirmationMessage, Color? color})

Properties

color Color?
final
confirmationMessage String?
final
confirmationTitle String?
final
hashCode int
The hash code for this object.
no setterinherited
iconData IconData?
final
isMain bool
final
isSecondary bool
final
needConfirmation bool
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWidget(BuildContext context) Widget
Converte in widget bottone appropriato in base ai flag.

Operators

operator ==(Object other) bool
The equality operator.
inherited