AppState class

Inheritance

Constructors

AppState()

Properties

aiButtonBuilder Widget Function(BuildContext context, VoidCallback onPressed)?
getter/setter pair
aiButtonPosition AiButtonPosition
getter/setter pair
aiChatOpen bool
getter/setter pair
fromNotification bool
getter/setter pair
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isInitialized bool
getter/setter pair
maintenanceMode bool
getter/setter pair
profilePosition ProfilePosition
getter/setter pair
refreshList ↔ BehaviorSubject<bool>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldRefresh bool
no setter
showAiButton bool
getter/setter pair
theme ThemeMode
no setter
themeMode ThemeMode
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
changeEndDrawer(bool value) → void
changeTheme() → void
completeInitialization() → void
dispose() → void
Discards any resources used by the object.
override
markForRefresh() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
resetError() → void
setMaintenanceMode(bool value) → void
toggleAiChat() → void
toString() String
A string representation of this object.
inherited
updateLocale(BuildContext context, Locale locale) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited