ThemeProvider class
- Inheritance
-
- Object
- ChangeNotifier
- ThemeProvider
- Annotations
-
- @Deprecated('Use AppThemeState — will be removed in 5.0')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isDarkMode → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeMode → ThemeMode
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
override
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setThemeMode(
ThemeMode mode) → Future< void> -
toggleTheme(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited