Module class abstract

Constructors

Module()

Properties

hashCode int
The hash code for this object.
no setterinherited
moduleRoute CLRoute
no setter
routes List<ModularRoute>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configureRoutes({String modulePath = '', bool topLevel = false, String? parentModuleName, String? parentModulePath, String parentRoutePath = ''}) List<RouteBase>
Synchronous route configuration entry point.
configureRoutesAsync({String modulePath = '', bool topLevel = false, String? parentModuleName, String? parentModulePath, String parentRoutePath = ''}) Future<List<RouteBase>>
Asynchronous variant of configureRoutes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited