CLPageData class

Wrapper for passing data between pages without exposing it in the URL.

Constructors

CLPageData(Map<String, dynamic> _data)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T>(String key) → T?
has(String key) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) CLPageData

Constants

empty → const CLPageData