CLThemeProvider class
Provider generico per iniettare un tema CLTheme custom nell'app.
Usalo come ChangeNotifierProvider alla radice del widget tree:
ChangeNotifierProvider(
create: (_) => CLThemeProvider(
lightTheme: const LightModeTheme(primary: Color(0xFFFF5722)),
darkTheme: const DarkModeTheme(primary: Color(0xFFFF7043)),
),
child: MaterialApp(...),
)
Se non viene fornito alcun tema, usa i default LightModeTheme / DarkModeTheme.
- Inheritance
-
- Object
- ChangeNotifier
- CLThemeProvider
Constructors
- CLThemeProvider({CLTheme? lightTheme, CLTheme? darkTheme})
Properties
- darkTheme → CLTheme
-
Tema dark corrente.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- lightTheme → CLTheme
-
Tema light corrente.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateThemes(
{CLTheme? light, CLTheme? dark}) → void - Aggiorna i temi a runtime e notifica i listener.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited