ModulePalette class
Palette colori per una suite (light + dark)
- Annotations
-
- @Deprecated('Specifico per Skillera. Usa CLThemeProvider con temi custom.')
Constructors
- ModulePalette({required Color lightPrimary, required Color lightSecondary, required Color darkPrimary, required Color darkSecondary})
-
const
Properties
- darkPrimary → Color
-
final
- darkSecondary → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lightPrimary → Color
-
final
- lightSecondary → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited