SkilleraModule enum

Suite principali dell'app Skillera con palette colori dedicate.

Nota: Questo enum è specifico per il progetto Skillera. Per progetti generici, usa CLThemeProvider con temi custom.

Inheritance
Available extensions
Annotations
  • @Deprecated('Specifico per Skillera. Usa CLThemeProvider con temi custom.')

Values

concierge → const SkilleraModule
id → const SkilleraModule
hr → const SkilleraModule
cert → const SkilleraModule
lms → const SkilleraModule

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SkilleraModule>
A constant List of the values in this enum, in order of their declaration.