SharedManager class

Constructors

SharedManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

prefs ↔ SharedPreferences?
getter/setter pair

Static Methods

getBool(String key) bool?
getInt(String key) int
getString(String key, {String defaultValue = ""}) String
getStringList(String key, {List<String>? defaultValue = const []}) List<String>?
initPrefs() → dynamic
remove(String key) Future<bool?>
setBool(String key, bool value) Future<bool?>
setInt(String key, int value) Future<int>
setString(String key, String value) Future<String?>
setStringList(String key, List<String> value) Future<List<String>?>