AlertManager class

Constructors

AlertManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

final

Static Methods

showDanger(String title, String message, {dynamic alertPosition = AlertPosition.bottom, dynamic onTap, dynamic closeOnTap = false}) → void
showDownloadPercentage(String title, String message, BehaviorSubject<double> downloadPercentageStream, {dynamic alertPosition = AlertPosition.leftBottomCorner, dynamic onTap, dynamic closeOnTap = false}) → void
showInfo(String title, String message, {dynamic alertPosition = AlertPosition.bottom, dynamic onTap, dynamic closeOnTap = false}) → void
showNotification(String title, String message, {dynamic alertPosition = AlertPosition.rightTopCorner, dynamic onTap, dynamic closeOnTap = false}) → void
showPrimary(String title, String message, {dynamic alertPosition = AlertPosition.bottom, dynamic onTap, dynamic closeOnTap = false}) → void
showSecondary(String title, String message, {dynamic alertPosition = AlertPosition.bottom, dynamic onTap, dynamic closeOnTap = false}) → void
showSuccess(String title, String message, {dynamic alertPosition = AlertPosition.bottom, dynamic onTap, dynamic closeOnTap = false}) → void
showWarning(String title, String message, {dynamic alertPosition = AlertPosition.bottom, dynamic onTap, dynamic closeOnTap = false}) → void