CLSoftButton class

Inheritance
Available extensions

Constructors

CLSoftButton({Key? key, required Color color, required String text, required dynamic onTap(), required BuildContext context, required IconAlignment iconAlignment, bool needConfirmation = false, String? confirmationMessage, IconData? iconData, List<List>? hugeIcon, double? width, bool isCompact = false})
const
CLSoftButton.danger({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, List<List>? hugeIcon, double? width, bool needConfirmation = false, String? confirmationMessage, bool isCompact = false})
factory
CLSoftButton.info({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, List<List>? hugeIcon, double? width, bool needConfirmation = false, String? confirmationMessage, bool isCompact = false})
factory
CLSoftButton.primary({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, List<List>? hugeIcon, double? width, bool needConfirmation = false, String? confirmationMessage, bool isCompact = false})
factory
CLSoftButton.secondary({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, List<List>? hugeIcon, double? width, bool needConfirmation = false, String? confirmationMessage, bool isCompact = false})
factory
CLSoftButton.success({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, List<List>? hugeIcon, double? width, bool needConfirmation = false, String? confirmationMessage, bool isCompact = false})
factory
CLSoftButton.warning({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, List<List>? hugeIcon, double? width, bool needConfirmation = false, String? confirmationMessage, bool isCompact = false})
factory

Properties

color Color
final
confirmationMessage String?
final
context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
hugeIcon List<List>?
final
iconAlignment IconAlignment
final
iconData IconData?
final
isCompact bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
needConfirmation bool
final
onTap → dynamic Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
width double?
final

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {bool hasBeenTriggered = false}) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CLSoftButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited