widgets/cl_ai_assistant/src/action/executors/node_finder library

Classes

NodeFinder
Locates SemanticsNodes on the live screen using a mix of label text, element type, available actions and positional heuristics.