ScrollHandler class

Handles scrolling to find off-screen elements.

When the AI tries to tap or interact with an element that isn't currently visible, this handler will scroll the nearest scrollable container to search for it.

Constructors

ScrollHandler({required SemanticsWalker walker})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollToFind({required String label, int maxScrolls = _maxScrollAttempts}) Future<SemanticsNode?>
Scroll to find an element with the given label.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited