AgentResponse class
Response from the ReAct agent after processing a user message.
Constructors
-
AgentResponse({required String text, List<
AgentAction> actions = const []}) -
const
Properties
-
actions
→ List<
AgentAction> -
All actions the agent performed during this turn.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The final natural language response to show the user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited