CardContent class

A rich card with optional image, title, subtitle, and action buttons.

Use for product cards, info cards, search results, etc.

Inheritance

Constructors

CardContent({required String title, String? subtitle, String? imageUrl, Uint8List? imageBytes, List<ChatButton>? actions})
const

Properties

actions List<ChatButton>?
final
hashCode int
The hash code for this object.
no setterinherited
imageBytes Uint8List?
final
imageUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited