ToolParameter class

A parameter definition for a tool.

Constructors

ToolParameter({required String type, required String description, List<String>? enumValues})
const

Properties

description String
Human-readable description of what this parameter does.
final
enumValues List<String>?
If set, restricts the value to one of these options.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
JSON Schema type: "string", "integer", "number", "boolean", "object", "array".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonSchema() Map<String, dynamic>
Convert to JSON Schema representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited