VoiceInputService class

Stub per il servizio di input vocale (speech-to-text).

La dipendenza speech_to_text non è inclusa nel progetto. Questa classe mantiene l'interfaccia pubblica per compatibilità ma non fornisce funzionalità reali.

Constructors

VoiceInputService()

Properties

hashCode int
The hash code for this object.
no setterinherited
isAvailable bool
no setter
isListening bool
no setter
resolvedLocaleId String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() Future<void>
dispose() → void
initialize() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startListening({required void onResult(String finalText, double confidence), void onPartial(String partialText)?, List<String> preferredLocales = const ['it_IT', 'en_US']}) Future<void>
stopListening() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited