CLCommandItem class

Constructors

CLCommandItem({required String id, required String label, String? description, IconData? icon, required VoidCallback onSelect, String? group})
const

Properties

description String?
final
group String?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
id String
final
label String
final
onSelect VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited