CLDatePicker class
Date picker in-theme (shadcn ShadDatePicker): trigger a bottone
(icona calendario + data/placeholder) che apre un popover ancorato con
CLCalendar. Varianti single e range. Nessun dialog Material.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CLDatePicker
- Available extensions
Constructors
-
CLDatePicker({Key? key, DateTime? selected, ValueChanged<
DateTime?> ? onChanged, String? placeholder, DateTime? firstDate, DateTime? lastDate, bool selectableDayPredicate(DateTime)?, double? width, bool closeOnSelect = true}) -
Selezione singola.
const
- CLDatePicker.range({Key? key, DateTime? rangeStart, DateTime? rangeEnd, void onRangeChanged(DateTime? start, DateTime? end)?, String? placeholder, DateTime? firstDate, DateTime? lastDate, bool selectableDayPredicate(DateTime)?, double? width, bool closeOnSelect = false})
-
Selezione di un intervallo.
const
Properties
- closeOnSelect → bool
-
Chiude il popover alla selezione (single: default true; range: false).
final
- firstDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRange → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lastDate → DateTime?
-
final
-
onChanged
→ ValueChanged<
DateTime?> ? -
final
- onRangeChanged → void Function(DateTime? start, DateTime? end)?
-
final
- placeholder → String?
-
final
- rangeEnd → DateTime?
-
final
- rangeStart → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectableDayPredicate → bool Function(DateTime)?
-
final
- selected → DateTime?
-
final
- width → double?
-
final
Methods
-
animateOnActionTrigger(
AnimationInfo animationInfo, {bool hasBeenTriggered = false}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
animateOnPageLoad(
AnimationInfo animationInfo) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CLDatePicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited