ClFilePicker class

Inheritance
Available extensions

Constructors

ClFilePicker({Key? key, dynamic onFilesPicked(List<CLMedia>)?, dynamic onFilePicked(CLMedia?)?, required bool isMultiple, required List<String> allowedExtensions, List<CLMedia>? initialFiles, required int maxNumberOfFile})
const
ClFilePicker.multiple({required dynamic onFilesPicked(List<CLMedia>), List<CLMedia>? initialFiles, required List<String> allowedExtensions, int maxNumberOfFile = 1000})
factory
ClFilePicker.single({required dynamic onPickedFile(CLMedia?), CLMedia? initialFile, required List<String> allowedExtensions})
factory

Properties

allowedExtensions List<String>
final
hashCode int
The hash code for this object.
no setterinherited
initialFiles List<CLMedia>?
final
isMultiple bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxNumberOfFile int
final
onFilePicked → dynamic Function(CLMedia?)?
final
onFilesPicked → dynamic Function(List<CLMedia>)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {bool hasBeenTriggered = false}) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ClFilePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited