CLInputGroupItem<T> class
Group item descriptor for CLInputGroup.
value is the unique key of the option, label is the displayed text.
Constructors
- CLInputGroupItem({required T value, required String label, IconData? icon})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited