CLCalendarDayData class

Modello per i dati di un giorno nel calendario

Constructors

CLCalendarDayData({required String dateKey, int primaryCount = 0, int secondaryCount = 0, bool hasWarning = false, Map<String, dynamic>? extra})

Properties

dateKey String
final
extra Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
hasWarning bool
final
primaryCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited