BaseGraph<E> class abstract

Base abstract graph widget that provides common functionality for all graph types

Inheritance
Implementers
Available extensions

Constructors

BaseGraph({Key? key, required BaseGraphController<E> controller, required Widget builder(NodeBuilderDetails<E> details), bool isDraggable = true, Curve curve = Curves.elasticOut, Duration duration = const Duration(milliseconds: 700), Paint? linePaint, List<PopupMenuEntry> optionsBuilder(E item)?, void onOptionSelect(E item, dynamic value)?, GraphArrowStyle arrowStyle = const SolidGraphArrow(), double cornerRadius = 10.0, LineEndingType lineEndingType = LineEndingType.arrow, CustomInteractiveViewerController? viewerController, InteractionConfig? interactionConfig, KeyboardConfig? keyboardConfig, ZoomConfig? zoomConfig, FocusNode? focusNode})

Properties

arrowStyle GraphArrowStyle
final
builder Widget Function(NodeBuilderDetails<E> details)
The builder function used to build the nodes
final
controller BaseGraphController<E>
The controller that manages the data and layout
final
cornerRadius double
final
curve Curve
final
duration Duration
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
interactionConfig InteractionConfig?
final
isDraggable bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardConfig KeyboardConfig?
final
lineEndingType LineEndingType
final
linePaint Paint
final
onOptionSelect → void Function(E item, dynamic value)?
final
optionsBuilder List<PopupMenuEntry> Function(E item)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewerController CustomInteractiveViewerController?
Callback to expose the interactive viewer controller
final
zoomConfig ZoomConfig?
final

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {bool hasBeenTriggered = false}) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited