BaseGraphState<E, T extends BaseGraph<E>> class abstract

Base state class for graph widgets

Inheritance
Implementers

Constructors

BaseGraphState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
controller BaseGraphController<E>
no setter
draggedID String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastDraggedNode Node<E>?
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
overlapping List<Node<E>>
getter/setter pair
overlappingNodes List<Node<E>>
no setter
panDownPosition Offset?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewerController CustomInteractiveViewerController
latefinal
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildEdges() Widget
Build the lines/edges between nodes
buildGraphElements(BuildContext context) List<Widget>
Build the elements of the graph
buildNodes(BuildContext context, {List<Node<E>>? nodesToDraw, bool hidden = false, int level = 1}) List<Widget>
Build the nodes of the graph
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
handleTapDown(TapDownDetails details) → void
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showNodeMenu(BuildContext context, Node<E> node) Future<void>
startDragging(Node<E> node) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toggleHideNodes(Node<E> node, bool? hide, bool center) → void
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateDragging(Node<E> node, DragUpdateDetails details) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited