Node<E> class

Represents a node in a graph

Constructors

Node({required E data, Offset position = Offset.zero, bool hideNodes = false})
Creates a new node with the given data

Properties

data → E
The data that the node contains (custom data type)
final
hashCode int
The hash code for this object.
no setterinherited
hideNodes bool
Whether to hide/collapse subnodes
getter/setter pair
position Offset
The position of the node in the graph
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

distance(Node other) Offset
Calculates the offset distance between this node and another node
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
The squared distance between nodes (faster calculation than actual distance)
override

Operators

operator ==(Object other) bool
The equality operator.
inherited