widgets/cl_org_chart/src/common/node_builder_details library

Classes

NodeBuilderDetails<T>
Contains all necessary properties that are passed to the node builder function to customize the appearance and behavior of each node in the graph.