QuadTreeStats class
Statistics about a QuadTree's structure and performance
Constructors
- QuadTreeStats({required int totalNodes, required int leafQuadrants, required int maxDepth, required Rect bounds})
-
const
Properties
- averageNodesPerLeaf → double
-
Average nodes per leaf quadrant
no setter
- bounds → Rect
-
final
- efficiencyRatio → double
-
Efficiency ratio (lower is better, ideal is close to maxNodesPerQuadrant)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- leafQuadrants → int
-
final
- maxDepth → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalNodes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited