GenogramState<E> class

Inheritance

Constructors

GenogramState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
controller GenogramController<E>
no setteroverride
draggedID String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
lastDraggedNode Node<E>?
getter/setter pairinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
overlapping List<Node<E>>
getter/setter pairinherited
overlappingNodes List<Node<E>>
no setterinherited
panDownPosition Offset?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewerController CustomInteractiveViewerController
latefinalinherited
widget Genogram<E>
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildEdges() Widget
Build the lines/edges between nodes
override
buildGraphElements(BuildContext context) List<Widget>
Build the elements of the graph
override
buildNodes(BuildContext context, {List<Node<E>>? nodesToDraw, bool hidden = false, int level = 1}) List<CustomAnimatedPositioned>
Build the nodes of the graph
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant Genogram<E> oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
finishDragging(Node<E> node) → void
handleTapDown(TapDownDetails details) → void
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showNodeMenu(BuildContext context, Node<E> node) Future<void>
inherited
startDragging(Node<E> node) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toggleHideNodes(Node<E> node, bool? hide, bool center) → void
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateDragging(Node<E> node, DragUpdateDetails details) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited