GenogramConstants class

Constants specific to Genogram widget

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultBoxSize → const Size
Default box size for genogram nodes
defaultRunSpacing → const double
Default vertical spacing between generations
defaultSpacing → const double
Default spacing for genogram charts