CLPopupMenuItem class
Elemento di un CLPopupMenu.
Constructors
- CLPopupMenuItem({required Widget content, required VoidCallback onTap})
-
const
Properties
- content → Widget
-
Contenuto completo della riga (es. ListTile con icona e testo).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTap → VoidCallback
-
Callback al tap.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited