CLStatStripItem class
Voce di una CLStatStrip: icona tinta + valore + label, opzionalmente tappabile.
Constructors
- CLStatStripItem({required IconData icon, required String value, required String label, required Color color, VoidCallback? onTap})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited