CLUniversalRepeatable<T extends Object> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CLUniversalRepeatable
- Available extensions
Constructors
-
CLUniversalRepeatable({Key? key, required String label, required List<
UniversalRepeatableItem< items, required Future<T> >(List< searchCallback({Map<T> , dynamic)>String, dynamic> ? orderBy, int? page, int? perPage, Map<String, dynamic> ? searchBy}), required String searchColumn, required String valueToShow(T item), VoidCallback? onChanged, Widget itemBuilder(BuildContext context, T item)?, String dropdownHint = 'Seleziona', RepeatableFieldConfig config = RepeatableFieldConfig.onlyDropdown, double getOriginalPrice(T item)?, String? getDescription(T item)?, String addButtonText = 'Aggiungi', double calculateTotal()?}) -
const
Properties
- addButtonText → String
-
final
- calculateTotal → double Function()?
-
final
- config → RepeatableFieldConfig
-
final
- dropdownHint → String
-
final
- getDescription → String? Function(T item)?
-
final
- getOriginalPrice → double Function(T item)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → Widget Function(BuildContext context, T item)?
-
final
-
items
→ List<
UniversalRepeatableItem< T> > -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
final
- onChanged → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchCallback
→ Future<
(List< Function({Map<T> , dynamic)>String, dynamic> ? orderBy, int? page, int? perPage, Map<String, dynamic> ? searchBy}) -
final
- searchColumn → String
-
final
- valueToShow → String Function(T item)
-
final
Methods
-
animateOnActionTrigger(
AnimationInfo animationInfo, {bool hasBeenTriggered = false}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
animateOnPageLoad(
AnimationInfo animationInfo) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CLUniversalRepeatable< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited