RepeatableFieldConfig class

Configurazione universale per il repeatable

Constructors

RepeatableFieldConfig({bool showQuantity = false, bool showCustomPrice = false, String quantityLabel = 'Quantità', String priceLabel = 'Prezzo personalizzato (opzionale)', double dropdownWidth = 100, bool showOriginalPrice = true, bool quantityRequired = true, bool priceRequired = false, bool showInfoBox = false, String? infoBoxText, Color? infoBoxColor, IconData? infoBoxIcon, bool showTotalBox = false, String? totalBoxLabel})
const

Properties

final
hashCode int
The hash code for this object.
no setterinherited
infoBoxColor Color?
final
infoBoxIcon IconData?
final
infoBoxText String?
final
priceLabel String
final
priceRequired bool
final
quantityLabel String
final
quantityRequired bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCustomPrice bool
final
showInfoBox bool
final
showOriginalPrice bool
final
showQuantity bool
final
showTotalBox bool
final
totalBoxLabel String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited