UniversalRepeatableItem<T extends Object> class
Constructors
- UniversalRepeatableItem({T? selectedItem, int? initialQuantity, double? initialPrice})
Properties
- customPrice → double?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- priceController ↔ TextEditingController?
-
getter/setter pair
- quantity → int
-
no setter
- quantityController ↔ TextEditingController?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedItem ↔ T?
-
getter/setter pair
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited