CLPressableState class

Stato interattivo risolto, passato al builder di CLPressable.

Annotations

Constructors

CLPressableState({bool hovered = false, bool pressed = false, bool focused = false, bool disabled = false})
const

Properties

disabled bool
final
enabled bool
no setter
focused bool
final
hashCode int
The hash code for this object.
no setteroverride
hovered bool
final
idle bool
Nessuno stato interattivo attivo (né hover, né press, né focus, né disabled).
no setter
pressed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override