ShellBack class
Intento "indietro": presente solo se la pagina può tornare indietro
(es. un dettaglio). null negli elenchi root.
- Annotations
Constructors
- ShellBack({required VoidCallback onTap, String? tooltip})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTap → VoidCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited