ShellCustom class
Escape hatch per controlli non standard (es. stepper mesi di un calendario).
Il builder DEVE catturare i controller per riferimento, NON via
context.read (verrebbe costruito sotto lo shell, antenato sbagliato).
- Annotations
Constructors
- ShellCustom(WidgetBuilder builder, {String? id})
-
const
Properties
- builder → WidgetBuilder
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited