ShellSearch class

Campo ricerca generico. Il controller è POSSEDUTO dalla pagina e passato per riferimento.

Annotations

Constructors

ShellSearch({required TextEditingController controller, String? hint, ValueChanged<String>? onChanged})
const

Properties

controller TextEditingController
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
onChanged ValueChanged<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited