onPressed property
void Function(T)
onPressed
final
Callback invoked with the row item when the action is tapped.
Implementation
final void Function(T) onPressed;
Callback invoked with the row item when the action is tapped.
final void Function(T) onPressed;