BaseTableColumn<TType extends Object> class abstract

Implementers

Constructors

BaseTableColumn({required String? id, required Widget title, required Widget titleBuilder(BuildContext context)?, required bool sortable, required bool isNumeric, required double? sizeFactor, required bool? isMain, bool isSubtitle = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
final
isMain bool?
final
isNumeric bool
final
isSubtitle bool
Mobile: se true, questa colonna fa da sottotitolo nella card. Default false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeFactor double?
final
sortable bool
final
title Widget
final
titleBuilder WidgetBuilder?
final

Methods

buildCell(TType item, int rowIndex) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited