CLTableStyle class

Override colori per-istanza di PagedDataTable. Ogni campo null -> token CLTheme.

Constructors

CLTableStyle({Color? primary, Color? searchFill, Color? headerBackground, Color? buttonFill, Color? border})
const

Properties

border Color?
final
buttonFill Color?
final
hashCode int
The hash code for this object.
no setterinherited
headerBackground Color?
final
primary Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchFill Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeOf(BuildContext c) CLTableStyle?