EditableTableColumn<TType extends Object, TValue extends Object> class
abstract
Defines a BaseTableColumn that allows the content of a cell to be modified, updating the underlying item too.
- Inheritance
-
- Object
- BaseTableColumn<
TType> - EditableTableColumn
Constructors
-
EditableTableColumn({required Setter<
TType, TValue> setter, required Getter<TType, TValue> getter, required String? id, required Widget title, required Widget titleBuilder(BuildContext context)?, required bool sortable, required bool isNumeric, required double? sizeFactor, required bool? isMain, bool isSubtitle = false}) -
const
Properties
-
getter
→ Getter<
TType, TValue> -
A function that returns the value that is going to be edited.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
finalinherited
- isMain → bool?
-
finalinherited
- isNumeric → bool
-
finalinherited
- isSubtitle → bool
-
Mobile: se true, questa colonna fa da sottotitolo nella card. Default false.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setter
→ Setter<
TType, TValue> -
Function called when the value of the cell changes, and must update the underlying
TType, returning true if it could be updated, otherwise, false.final - sizeFactor → double?
-
finalinherited
- sortable → bool
-
finalinherited
- title → Widget
-
finalinherited
- titleBuilder → WidgetBuilder?
-
finalinherited
Methods
-
buildCell(
TType item, int rowIndex) → Widget -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited