advancePage method
Advances to the next page.
If there is no next page, this method will fail. The future completes when the fetch is done.
Implementation
Future<void> advancePage() => _state.nextPage();
Advances to the next page.
If there is no next page, this method will fail. The future completes when the fetch is done.
Future<void> advancePage() => _state.nextPage();