backPage method
Backs off to the previous page.
If there is no previous page, this method will fail. The future completes when the fetch is done.
Implementation
Future<void> backPage() => _state.previousPage();
Backs off to the previous page.
If there is no previous page, this method will fail. The future completes when the fetch is done.
Future<void> backPage() => _state.previousPage();