modifyRowsValue method
Updates every item from the current resultset that matches predicate and rebuilds it.
Keep in mind this method will iterate over every item in the current dataset, so, if the dataset is large, it can be costly.
Implementation
void modifyRowsValue(bool Function(TResult element) predicate,
void Function(TResult item) update) {
int index = 0;
for (final item in _state._items) {
if (predicate(item)) {
update(item);
_state._rowsState[index].refresh();
}
index++;
}
}