refresh method

Future<void> refresh({
  1. bool currentDataset = true,
})

Refreshes the table fetching from source again. If currentDataset is true, it will only refresh the current viewing resultset, otherwise, it will start from page 1.

The future completes when the fetch is done.

Implementation

Future<void> refresh({bool currentDataset = true}) {
  // No-op se il table non è montato (tab lazy non ancora aperto): al primo
  // mount farà comunque la sua fetch iniziale, quindi non c'è nulla da
  // rinfrescare e si evita il LateInitializationError su `_state`.
  if (!_attached) return Future.value();
  return _state._refresh(initial: !currentDataset);
}