inline property
When true, this action renders as a plain compact icon button directly inline in the row, before the 3-dot popup menu.
Implementation
final bool inline;
When true, this action renders as a plain compact icon button directly inline in the row, before the 3-dot popup menu.
final bool inline;