CLApp class
Entry point generico per le app basate su genai_components.
Uso:
void main() => CLApp.run(MySkilleraConfig());
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
run(
CLAppConfig config) → Future< void> - Inizializza e lancia l'app con la configurazione fornita.