Typography class abstract

--- Typography ----------------------------------------------------------

Implementers

Constructors

Typography()

Properties

bodyLabel TextStyle
no setter
bodyLabelTableHead TextStyle
no setter
bodyText TextStyle
no setter
hashCode int
The hash code for this object.
no setterinherited
heading1 TextStyle
no setter
heading2 TextStyle
no setter
heading3 TextStyle
no setter
heading4 TextStyle
no setter
heading5 TextStyle
no setter
heading6 TextStyle
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smallLabel TextStyle
no setter
smallText TextStyle
no setter
subTitle TextStyle
no setter
title TextStyle
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited