CLGraphEdge class
Constructors
- CLGraphEdge({required String id, required String fromNodeId, required String toNodeId, required CLGraphEdgeKind kind, })
-
const
Properties
- fromNodeId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Arco strutturale (conta per il layout) ma NON disegnato. Utile per il
containment verso risorse già collegate visivamente da una freccia prereq.
final
- id → String
-
final
- kind → CLGraphEdgeKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toNodeId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited