KeyboardConfig class
Configuration for keyboard controls in CustomInteractiveViewer.
- Annotations
Constructors
- KeyboardConfig({bool enableKeyboardControls = true, double keyboardPanDistance = 20.0, double keyboardZoomFactor = 1.1, bool enableKeyRepeat = true, Duration keyRepeatInitialDelay = const Duration(milliseconds: 500), Duration keyRepeatInterval = const Duration(milliseconds: 50), bool animateKeyboardTransitions = true, Duration keyboardAnimationDuration = const Duration(milliseconds: 200), Curve keyboardAnimationCurve = Curves.easeOutCubic, bool invertArrowKeyDirection = false})
-
Creates a keyboard configuration.
const
- KeyboardConfig.disabled()
-
Creates a configuration with keyboard controls disabled.
const
- KeyboardConfig.fast()
-
Creates a configuration with fast, responsive keyboard controls.
const
Properties
- animateKeyboardTransitions → bool
-
Whether to animate transitions when using keyboard controls.
final
- enableKeyboardControls → bool
-
Whether to enable keyboard controls.
final
- enableKeyRepeat → bool
-
Whether to enable key repeat for keyboard controls.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- invertArrowKeyDirection → bool
-
Whether to invert the direction of arrow keys.
If true, pressing left moves view left.
If false, pressing left moves content right.
final
- keyboardAnimationCurve → Curve
-
Animation curve for keyboard transitions.
final
- keyboardAnimationDuration → Duration
-
Duration of keyboard transition animations.
final
- keyboardPanDistance → double
-
The distance to pan when using keyboard arrow keys.
final
- keyboardZoomFactor → double
-
The factor by which to zoom when using keyboard zoom keys.
final
- keyRepeatInitialDelay → Duration
-
The delay before key repeat begins.
final
- keyRepeatInterval → Duration
-
The interval between repeated key actions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? enableKeyboardControls, double? keyboardPanDistance, double? keyboardZoomFactor, bool? enableKeyRepeat, Duration? keyRepeatInitialDelay, Duration? keyRepeatInterval, bool? animateKeyboardTransitions, Duration? keyboardAnimationDuration, Curve? keyboardAnimationCurve, bool? invertArrowKeyDirection}) → KeyboardConfig - Creates a copy of this configuration with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override