CLButton class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CLButton
- Available extensions
Constructors
- CLButton({Key? key, Color? backgroundColor, required String text, required dynamic onTap(), required BuildContext context, required IconAlignment iconAlignment, IconData? iconData, bool needConfirmation = false, String? confirmationMessage, double? iconSize, double? width, TextStyle? textStyle, Color? iconColor, Widget? hugeIcon, bool isCompact = false, bool enabled = true, String? tooltip, bool? loading, String? semanticLabel, bool fullWidth = false, bool haptic = true, double? borderRadius})
-
const
- CLButton.danger({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, double? iconSize, bool needConfirmation = false, String? confirmationMessage, double? width, TextStyle? textStyle, Color? iconColor, Widget? hugeIcon, bool isCompact = false, bool enabled = true, String? tooltip, bool? loading, String? semanticLabel, bool fullWidth = false, bool haptic = true, double? borderRadius})
-
factory
- CLButton.info({required String text, required dynamic onTap(), required BuildContext context, double? iconSize, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, bool needConfirmation = false, String? confirmationMessage, double? width, TextStyle? textStyle, Color? iconColor, Widget? hugeIcon, bool isCompact = false, bool enabled = true, String? tooltip, bool? loading, String? semanticLabel, bool fullWidth = false, bool haptic = true, double? borderRadius})
-
factory
- CLButton.primary({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, bool needConfirmation = false, String? confirmationMessage, double? iconSize, double? width, TextStyle? textStyle, Color? iconColor, Widget? hugeIcon, bool isCompact = false, bool enabled = true, String? tooltip, bool? loading, String? semanticLabel, bool fullWidth = false, bool haptic = true, double? borderRadius})
-
factory
- CLButton.secondary({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, bool needConfirmation = false, String? confirmationMessage, double? iconSize, double? width, TextStyle? textStyle, Color? iconColor, Widget? hugeIcon, bool isCompact = false, bool enabled = true, String? tooltip, bool? loading, String? semanticLabel, bool fullWidth = false, bool haptic = true, double? borderRadius})
-
factory
- CLButton.success({required String text, required dynamic onTap(), required BuildContext context, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, double? iconSize, bool needConfirmation = false, String? confirmationMessage, double? width, TextStyle? textStyle, Color? iconColor, Widget? hugeIcon, bool isCompact = false, bool enabled = true, String? tooltip, bool? loading, String? semanticLabel, bool fullWidth = false, bool haptic = true, double? borderRadius})
-
factory
- CLButton.warning({required String text, required dynamic onTap(), required BuildContext context, double? iconSize, IconAlignment iconAlignment = IconAlignment.start, IconData? icon, bool needConfirmation = false, String? confirmationMessage, double? width, TextStyle? textStyle, Color? iconColor, Widget? hugeIcon, bool isCompact = false, bool enabled = true, String? tooltip, bool? loading, String? semanticLabel, bool fullWidth = false, bool haptic = true, double? borderRadius})
-
factory
Properties
- backgroundColor → Color?
-
final
- borderRadius → double?
-
Override del raggio di angolo. Se
nullusaSizes.radiusControl(6, scala shadcn).final - confirmationMessage → String?
-
final
- context → BuildContext
-
final
- enabled → bool
-
Se
false, disabilita input e applica opacità ridotta.final - fullWidth → bool
-
Espande il bottone alla larghezza disponibile del parent (zucchero per
width: double.infinity).final - haptic → bool
-
Se
true(default), emette unHapticFeedback.selectionClick()al press (iOS/Android).final - hashCode → int
-
The hash code for this object.
no setterinherited
- hugeIcon → Widget?
-
final
- iconAlignment → IconAlignment
-
final
- iconColor → Color?
-
final
- iconData → IconData?
-
final
- iconSize → double?
-
final
- isCompact → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loading → bool?
-
Override esterno dello stato di loading. Se
null, usa lo stato interno del mixin async.final - needConfirmation → bool
-
final
- onTap → dynamic Function()
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Label semantica per screen reader.
final
- text → String
-
final
- textStyle → TextStyle?
-
final
- tooltip → String?
-
Tooltip mostrato al hover/long-press. Utile soprattutto per icon-only.
final
- width → double?
-
final
Methods
-
animateOnActionTrigger(
AnimationInfo animationInfo, {bool hasBeenTriggered = false}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
animateOnPageLoad(
AnimationInfo animationInfo) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CLButton> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited