ButtonsContent class
A group of tappable quick-reply buttons.
Rendered as a flowing row of chips (or a vertical list for ButtonLayout.column). Tapping a button sends its label as the user's message and disables all buttons in the group to prevent double-taps.
- Inheritance
-
- Object
- ChatContent
- ButtonsContent
Constructors
-
ButtonsContent({required List<
ChatButton> buttons, ButtonLayout layout = ButtonLayout.wrap}) -
const
Properties
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → ButtonLayout
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited