parentLabels property
Labels of parent and sibling nodes, used for disambiguation when multiple elements share the same label (e.g., multiple "Add" buttons in a product list — the parentLabels contain the product name).
Implementation
final List<String> parentLabels;