CLCalendar class
Calendario in-theme, modello shadcn ShadCalendar (letto dal sorgente
flutter-shadcn-ui). Header con nav mese, riga giorni settimana, griglia.
Celle su CLPressable + CLToneStyle: selected = solid primary · today =
accent grigio (shadcn today=secondary=grigio; il ns secondary è blu brand)
· normale = ghost · fuori-mese = opacity .5 muted. Pill giorno 36 centrato;
range riempie la cella (barra contigua). Settimana lun-first, IT.
Feature (allineate alla doc shadcn): showWeekNumbers, showOutsideDays,
fixedWeeks, hideNavigation, hideWeekdayNames, numberOfMonths,
captionLayout, fromMonth/toMonth (bound nav), min/max (conteggio
multiple / lunghezza range).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CLCalendar
- Available extensions
Constructors
-
CLCalendar({Key? key, DateTime? selected, DateTime? initialMonth, ValueChanged<
DateTime> ? onChanged, DateTime? firstDate, DateTime? lastDate, bool selectableDayPredicate(DateTime)?, bool showWeekNumbers = false, bool showOutsideDays = true, bool fixedWeeks = false, bool hideWeekdayNames = false, int numberOfMonths = 1, CLCalendarCaptionLayout captionLayout = CLCalendarCaptionLayout.label, DateTime? fromMonth, DateTime? toMonth}) -
Selezione singola.
const
-
CLCalendar.multiple({Key? key, List<
DateTime> selectedDates = const [], DateTime? initialMonth, ValueChanged<List< ? onMultipleChanged, DateTime? firstDate, DateTime? lastDate, bool selectableDayPredicate(DateTime)?, int? min, int? max, bool showWeekNumbers = false, bool showOutsideDays = true, bool fixedWeeks = false, bool hideWeekdayNames = false, int numberOfMonths = 1, CLCalendarCaptionLayout captionLayout = CLCalendarCaptionLayout.label, DateTime? fromMonth, DateTime? toMonth})DateTime> > -
Selezione multipla (più giorni).
min/max= conteggio giorni.const - CLCalendar.range({Key? key, DateTime? rangeStart, DateTime? rangeEnd, DateTime? initialMonth, void onRangeChanged(DateTime? start, DateTime? end)?, DateTime? firstDate, DateTime? lastDate, bool selectableDayPredicate(DateTime)?, int? min, int? max, bool showWeekNumbers = false, bool showOutsideDays = true, bool fixedWeeks = false, bool hideWeekdayNames = false, int numberOfMonths = 1, CLCalendarCaptionLayout captionLayout = CLCalendarCaptionLayout.label, DateTime? fromMonth, DateTime? toMonth})
-
Selezione di un intervallo (start–end).
min/max= lunghezza in giorni.const
Properties
- captionLayout → CLCalendarCaptionLayout
-
final
- firstDate → DateTime?
-
final
- fixedWeeks → bool
-
final
- fromMonth → DateTime?
-
Mese minimo/massimo navigabile (le frecce si disabilitano ai bordi; i
dropdown anno/mese si limitano a questo intervallo).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- hideWeekdayNames → bool
-
final
- initialMonth → DateTime?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lastDate → DateTime?
-
final
- max → int?
-
final
- min → int?
-
multiple = conteggio giorni; range = lunghezza intervallo (giorni).
final
- numberOfMonths → int
-
final
-
onChanged
→ ValueChanged<
DateTime> ? -
final
-
onMultipleChanged
→ ValueChanged<
List< ?DateTime> > -
final
- onRangeChanged → void Function(DateTime? start, DateTime? end)?
-
final
- rangeEnd → DateTime?
-
final
- rangeStart → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectableDayPredicate → bool Function(DateTime)?
-
final
- selected → DateTime?
-
final
-
selectedDates
→ List<
DateTime> -
final
- showOutsideDays → bool
-
final
- showWeekNumbers → bool
-
final
- toMonth → DateTime?
-
final
- variant → CLCalendarVariant
-
final
Methods
-
animateOnActionTrigger(
AnimationInfo animationInfo, {bool hasBeenTriggered = false}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
animateOnPageLoad(
AnimationInfo animationInfo) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CLCalendar> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited