CLDialog<T> class
abstract
Base class for CL dialogs with title, optional subtitle, and confirm/cancel actions.
Subclasses implement buildContent to provide the dialog body. The
onConfirm callback may be synchronous or asynchronous and its return
value is used as the result passed to Navigator.pop.
Example:
class MyDialog extends CLDialog<String> {
const MyDialog({super.key}) : super(title: 'Esempio');
@override
Widget buildContent(BuildContext context) => const Text('Body');
}
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CLDialog
- Available extensions
Constructors
-
CLDialog({Key? key, required String title, String? subtitle, VoidCallback? onCancel, FutureOr<
T?> onConfirm()?, String confirmLabel = 'Conferma', String cancelLabel = 'Annulla', Widget? headerLeading, bool showCloseButton = true, double maxWidth = 480, double? maxWidthFraction, bool scrollableBody = true}) -
Creates a CLDialog.
const
Properties
- cancelLabel → String
-
Label of the cancel button.
final
- confirmLabel → String
-
Label of the confirm button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerLeading → Widget?
-
Optional leading widget in the header (icon badge, avatar).
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxWidth → double
-
Max dialog width. Default
480.final - maxWidthFraction → double?
-
Larghezza massima come frazione della larghezza schermo (es.
0.6= 60%). Ha precedenza su maxWidth. Per dialog "larghi" (es. tabelle embedded).final - onCancel → VoidCallback?
-
Invoked when the user taps the cancel action, before the dialog pops.
final
-
onConfirm
→ FutureOr<
T?> Function()? -
Invoked when the user taps the confirm action. Its result is returned
to the caller of showDialog. If
null, the confirm button is hidden.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollableBody → bool
-
When
true(default) the body is wrapped in a scroll view. Setfalsewhen the content manages its own scrolling (e.g. an inner list/table).final - showCloseButton → bool
-
Whether to show the close (×) button in the header. Default
true.final - subtitle → String?
-
Optional subtitle rendered below the title and above buildContent.
final
- title → String
-
Title shown in the dialog header.
final
Methods
-
animateOnActionTrigger(
AnimationInfo animationInfo, {bool hasBeenTriggered = false}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
animateOnPageLoad(
AnimationInfo animationInfo) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
buildContent(
BuildContext context) → Widget - Builds the body of the dialog. Subclasses must override.
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show<
T> (BuildContext context, {required String title, required WidgetBuilder content, String? subtitle, Widget? headerLeading, bool showCloseButton = true, double maxWidth = 480, bool scrollableBody = true, FutureOr< T?> onConfirm()?, VoidCallback? onCancel, String confirmLabel = 'Conferma', String cancelLabel = 'Annulla', bool barrierDismissible = true}) → Future<T?> -
Apre un CLDialog inline, senza sottoclasse. Ritorna il risultato di
onConfirm(onullse annullato/chiuso).