CLDropdown<T extends Object> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CLDropdown
- Available extensions
Constructors
-
CLDropdown({Key? key, required Widget itemBuilder(BuildContext, T), required String valueToShow(T), required String hint, Future<
(List< asyncSearchCallback({Map<T> , Object?)>String, dynamic> ? orderBy, int? page, int? perPage, Map<String, dynamic> ? searchBy})?, Future<List< syncSearchCallback(String)?, List<T> >T> items = const [], String? searchColumn, required bool isMultiple, required List<T> selectedValues, dynamic onSelectItem(T?)?, int length = 10, List<FormFieldValidator< ? validators, bool isEnabled = true, dynamic onSelectItems(List<String> >T> )?, dynamic onClearItem()?, Color? fillColor, bool isCompact = false}) -
const
-
CLDropdown.multipleAsync({Key? key, required String hint, required Future<
(List< searchCallback({Map<T> , Object?)>String, dynamic> ? orderBy, int? page, int? perPage, Map<String, dynamic> ? searchBy})?, required dynamic searchColumn, required Widget itemBuilder(BuildContext, T), required String valueToShow(T), required dynamic onSelectItems(List<T> )?, List<FormFieldValidator< ? validators, List<String> >T> selectedValues = const [], int length = 10, bool isCompact = false}) -
factory
-
CLDropdown.multipleSync({Key? key, required String hint, required List<
T> items, required Widget itemBuilder(BuildContext, T), required Future<List< searchCallback(String value), required String valueToShow(T), required dynamic onSelectItems(List<T> >T> )?, List<FormFieldValidator< ? validators, List<String> >T> selectedValues = const [], int length = 10, bool isCompact = false}) -
factory
-
CLDropdown.singleAsync({Key? key, required String hint, required Future<
(List< searchCallback({Map<T> , Object?)>String, dynamic> ? orderBy, int? page, int? perPage, Map<String, dynamic> ? searchBy})?, required dynamic searchColumn, required Widget itemBuilder(BuildContext, T), required String valueToShow(T), List<FormFieldValidator< ? validators, bool isEnabled = true, int length = 10, T? selectedValues, required dynamic onSelectItem(T?)?, dynamic onClearItem()?, Color? fillColor, bool isCompact = false})String> > -
factory
-
CLDropdown.singleSync({Key? key, required String hint, required List<
T> items, required String valueToShow(T), Future<List< searchCallback(String)?, required Widget itemBuilder(BuildContext, T), required dynamic onSelectItem(T?)?, List<T> >FormFieldValidator< ? validators, int length = 10, T? selectedValues, dynamic onClearItem()?, Color? fillColor, bool isCompact = false})String> > -
factory
Properties
-
asyncSearchCallback
→ Future<
(List< Function({Map<T> , Object?)>String, dynamic> ? orderBy, int? page, int? perPage, Map<String, dynamic> ? searchBy})? -
final
- fillColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String
-
final
- isCompact → bool
-
Se
true, campo a 32px e item del menu più densi.final - isEnabled → bool
-
final
- isMultiple → bool
-
final
- itemBuilder → Widget Function(BuildContext, T)
-
final
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- length → int
-
final
- onClearItem → dynamic Function()?
-
final
- onSelectItem → dynamic Function(T?)?
-
final
-
onSelectItems
→ dynamic Function(List<
T> )? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchColumn → String?
-
final
-
selectedValues
→ List<
T> -
final
-
syncSearchCallback
→ Future<
List< Function(String)?T> > -
final
-
validators
→ List<
FormFieldValidator< ?String> > -
final
- valueToShow → String Function(T)
-
final
Methods
-
animateOnActionTrigger(
AnimationInfo animationInfo, {bool hasBeenTriggered = false}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
animateOnPageLoad(
AnimationInfo animationInfo) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CLDropdown< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited