CLAttachedMedia class
Modello leggero per rappresentare un media allegato. Può essere esteso o mappato dal modello specifico del progetto.
Constructors
- CLAttachedMedia({required String id, String? url, String? originalName, String path = ''})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited