Genogram<E> class

A widget that displays an organizational chart

Inheritance
Available extensions

Constructors

Genogram({Key? key, required BaseGraphController<E> controller, required Widget builder(NodeBuilderDetails<E> details), bool isDraggable = true, Curve curve = Curves.elasticOut, Duration duration = const Duration(milliseconds: 700), Paint? linePaint, double cornerRadius = 10.0, GraphArrowStyle arrowStyle = const SolidGraphArrow(), LineEndingType lineEndingType = LineEndingType.arrow, List<PopupMenuEntry> optionsBuilder(E item)?, void onOptionSelect(E item, dynamic value)?, CustomInteractiveViewerController? viewerController, InteractionConfig? interactionConfig, KeyboardConfig? keyboardConfig, ZoomConfig? zoomConfig, FocusNode? focusNode, GenogramEdgeConfig edgeConfig = const GenogramEdgeConfig(), MarriageStatus marriageStatusProvider(E person, E spouse)?, void onDrop(E dragged, E target)?})

Properties

arrowStyle GraphArrowStyle
finalinherited
builder Widget Function(NodeBuilderDetails<E> details)
The builder function used to build the nodes
finalinherited
controller BaseGraphController<E>
The controller that manages the data and layout
finalinherited
cornerRadius double
finalinherited
curve Curve
finalinherited
duration Duration
finalinherited
edgeConfig GenogramEdgeConfig
Configuration for edge painter styling
final
focusNode FocusNode?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
interactionConfig InteractionConfig?
finalinherited
isDraggable bool
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardConfig KeyboardConfig?
finalinherited
lineEndingType LineEndingType
finalinherited
linePaint Paint
finalinherited
marriageStatusProvider MarriageStatus Function(E person, E spouse)?
Function to determine marriage status between two people
final
onDrop → void Function(E dragged, E target)?
final
onOptionSelect → void Function(E item, dynamic value)?
finalinherited
optionsBuilder List<PopupMenuEntry> Function(E item)?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewerController CustomInteractiveViewerController?
Callback to expose the interactive viewer controller
finalinherited
zoomConfig ZoomConfig?
finalinherited

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {bool hasBeenTriggered = false}) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() GenogramState<E>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited