widgets/cl_org_chart/src/genogram/marriage_style library
Classes
- DivorceDecorator
- A decorator that draws a diagonal line through a marriage line to indicate divorce
- MarriageDecorator
- Base abstract class for decorators that can be applied to marriage lines
- MarriageLineStyle
- Represents the style of a marriage line in a genogram
- MarriageStyle
- Represents the style of a specific marriage relationship