MarriageLineStyle class
Represents the style of a marriage line in a genogram
Constructors
-
MarriageLineStyle({Color color = Colors.black, double strokeWidth = 1.0, PaintingStyle paintStyle = PaintingStyle.stroke, List<
double> ? dashPattern}) -
Creates a new marriage line style
const
-
MarriageLineStyle.dashed({Color color = Colors.black, double strokeWidth = 1.0, List<
double> dashPattern = const [5, 5]}) -
Creates a marriage line style with a dashed line
factory
- MarriageLineStyle.solid({Color color = Colors.black, double strokeWidth = 1.0})
-
Creates a marriage line style with a solid line
factory
Properties
- color → Color
-
The color of the marriage line
final
-
dashPattern
→ List<
double> ? -
Optional dash pattern if using dashed lines
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- paintStyle → PaintingStyle
-
The style of the marriage line (solid, dashed, etc.)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double
-
The stroke width of the marriage line
final
Methods
-
copyWith(
{Color? color, double? strokeWidth, PaintingStyle? paintStyle, List< double> ? dashPattern}) → MarriageLineStyle - Creates a copy of this style with the given properties replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited