SurveyWidget class
Crea un form Survey
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SurveyWidget
- Available extensions
Constructors
-
SurveyWidget({Key? key, required List<
Question> initialData, Widget builder(BuildContext context, Question question, void update(List<String> ))?, String? defaultErrorText, void onSave(List<QuestionResult> questionResults)?, String? saveText}) -
const
Properties
-
builder
→ Widget Function(BuildContext context, Question question, void update(List<
String> ))? -
Funzione che ritorna un widget personalizzato da usare come campo, preferibilmente un FormField.
final
- defaultErrorText → String?
-
Parametro per configurare il messaggio di errore di default in caso di validazione fallita.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialData
→ List<
Question> -
La lista delle domande che definiscono il flusso del sondaggio.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onSave
→ void Function(List<
QuestionResult> questionResults)? -
Metodo opzionale da chiamare con le domande compilate finora.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saveText → String?
-
final
Methods
-
animateOnActionTrigger(
AnimationInfo animationInfo, {bool hasBeenTriggered = false}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
animateOnPageLoad(
AnimationInfo animationInfo) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SurveyWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited