CLTimePicker class
Time picker in-theme (shadcn ShadTimePicker): input a campi segmentati
(ore/minuti, opzionali secondi e periodo AM/PM). Emette TimeOfDay.
Nota: UX a campi (non il clock-dialog di Material showTimePicker).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CLTimePicker
- Available extensions
Constructors
-
CLTimePicker({Key? key, TimeOfDay? initial, ValueChanged<
TimeOfDay> ? onChanged, bool use24h = true, bool showSeconds = false, double? fieldWidth}) -
const
Properties
- fieldWidth → double?
-
Larghezza dei singoli campi.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initial → TimeOfDay?
-
Ora iniziale.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
TimeOfDay> ? -
Notificato a ogni cambio (ore/minuti
/periodo).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showSeconds → bool
-
Mostra anche il campo secondi (default
false).final - use24h → bool
-
true(default) = 24h;false= 12h con selettore AM/PM.final
Methods
-
animateOnActionTrigger(
AnimationInfo animationInfo, {bool hasBeenTriggered = false}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
animateOnPageLoad(
AnimationInfo animationInfo) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited