ShellContextControl class
Controllo contestuale legato al controller della pagina. Union GENERICA: bottone / ricerca / custom / reveal. Su desktop+tablet la pagina tiene i propri controlli inline; lo shell usa questi solo dove il design li ricolloca (riga alta del bottom mobile).
- Annotations
Constructors
- ShellContextControl.action(ShellAction action)
-
const
- ShellContextControl.custom(ShellCustom custom)
-
const
- ShellContextControl.reveal(ShellRevealControl reveal)
-
const
- ShellContextControl.search(ShellSearch search)
-
const
Properties
- action → ShellAction?
-
final
- custom → ShellCustom?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reveal → ShellRevealControl?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → ShellSearch?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited