inline property
When true, this action renders as a compact CLOutlineButton directly
inline in the row, before the 3-dot popup menu.
Implementation
final bool inline;
When true, this action renders as a compact CLOutlineButton directly
inline in the row, before the 3-dot popup menu.
final bool inline;