TableColumn<TType extends Object> class

Defines a simple BaseTableColumn that renders a cell based on cellBuilder

Inheritance

Constructors

TableColumn({required Widget title, required Widget cellBuilder(TType), double? sizeFactor = .1, bool isNumeric = false, bool sortable = false, String? id, bool? isMain = false})
const

Properties

cellBuilder Widget Function(TType)
final
hashCode int
The hash code for this object.
no setterinherited
id String?
finalinherited
isMain bool?
finalinherited
isNumeric bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeFactor double?
finalinherited
sortable bool
finalinherited
title Widget
finalinherited
titleBuilder WidgetBuilder?
finalinherited

Methods

buildCell(TType item, int rowIndex) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited